translate.storage.fpo

Package translate :: Package storage :: Module fpo |
[hide private]
[frames] | no frames]

# Module fpo

source code

Classes for the support of Gettext .po and .pot files.

This implementation assumes that cpo is working. This should not be used directly, but can be used once cpo has been established to work.

Classes | [hide private]
| pounit
| pofile A .po file containing various units

Variables | [hide private]
| lsep = `" "` Seperator for #: entries
| basic_header = `r'''msgid`...``

Imports: multistring, data, pocommon, base, cpo, encodingToUse, re, copy, cStringIO

Variables Details | [hide private]

  ### basic_header Value:
      r'''msgid ""
      msgstr ""
      "Content-Type: text/plain; charset=UTF-8\n"
      "Content-Transfer-Encoding: 8bit\n"
      '''